[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)
[![Documentation Status](https://readthedocs.org/projects/pyatmoslogger/badge/?version=latest)](https://pyatmoslogger.readthedocs.io/en/latest/?badge=latest)
[![DOI](https://zenodo.org/badge/633838435.svg)](https://zenodo.org/badge/latestdoi/633838435)

<img src="https://raw.githubusercontent.com/marcusgmueller/pyAtmosLogger/master/docs/_static/images/pyAtmosLogger.png" width="200" style="margin: 20px 10px"/>

> **Warning**
> This software is still in development.

Python data logger for Atmospheric Application. This software allows data logging for multiple types of atmospherical instruments with a simple python-based syntax. Data can be automaticly converted to NetCDF-fileformat.

# Documentation

The official documentation is available [here](https://pyatmoslogger.readthedocs.io/en/latest/index.html).
